KerningGroups

Struct KerningGroups 

pub struct KerningGroups {
    pub groups: BTreeMap<KernGroup, BTreeSet<GlyphName>>,
    pub locations: BTreeSet<NormalizedLocation>,
    pub old_to_new_group_names: BTreeMap<KernGroup, KernGroup>,
}
IR representation of kerning groups.

In UFO terms, roughly groups.plist plus the set of locations that can have kerning.

Fields

groups: BTreeMap<KernGroup, BTreeSet<GlyphName>>locations: BTreeSet<NormalizedLocation>

The locations that have kerning defined.

Must be a subset of the master locations.

old_to_new_group_names: BTreeMap<KernGroup, KernGroup>

Optional group renaming map, meant for KerningInstance to consume

The rhs should be the name used in the groups map.