StaticMetadata

Struct StaticMetadata 

pub struct StaticMetadata {
Show 13 fields pub units_per_em: u16, pub all_source_axes: Axes, pub axes: Axes, pub named_instances: Vec<NamedInstance>, pub variation_model: VariationModel, pub number_values: HashMap<NormalizedLocation, BTreeMap<SmolStr, OrderedFloat<f64>>>, pub names: HashMap<NameKey, String>, pub postscript_names: Option<PostscriptNames>, pub italic_angle: OrderedFloat<f64>, pub build_vertical: bool, pub misc: MiscMetadata, pub gdef_categories: GdefCategories, pub variations: Option<VariableFeature>, /* private fields */
}
Global font info that cannot vary across the design space.

For example, upem, axis definitions, etc, as distinct from metadata that varies across design space such as ascender/descender.

Fields

units_per_em: u16all_source_axes: Axes

Every axis used by the font being compiled, including point axes.

This is relatively rarely what you want.

axes: Axes

Every variable (non-point) axis used by the font being compiled.

If empty this is a static font.

named_instances: Vec<NamedInstance>

Named locations in variation space

variation_model: VariationModel

A model of how variation space is split into regions that have deltas.

This copy includes all locations used in the entire font. That is, every location any glyph has an instance. Use of a location not in the global model is an error. This model enforces the no delta at the default location constraint used in things like gvar.

number_values: HashMap<NormalizedLocation, BTreeMap<SmolStr, OrderedFloat<f64>>>

Glyphsapp only; named numbers defined per-master

names: HashMap<NameKey, String>postscript_names: Option<PostscriptNames>italic_angle: OrderedFloat<f64>

Italic angle in counter-clockwise degrees from the vertical. Zero for upright fonts, negative for right-leaning fonts. See https://learn.microsoft.com/en-us/typography/opentype/spec/post.

build_vertical: bool

Records whether this font contains sufficient non-default vertical data to warrant building a vhea and vmtx table. (The criteria for Glyphs and UFO sources is different.)

misc: MiscMetadata

Miscellaneous font-wide data that didn’t seem worthy of top billing

gdef_categories: GdefCategoriesvariations: Option<VariableFeature>

Feature variation rules

Implementations

Source

impl StaticMetadata

pub fn new( units_per_em: u16, names: HashMap<NameKey, String>, axes: Vec<Axis>, named_instances: Vec<NamedInstance>, global_locations: HashSet<NormalizedLocation>, postscript_names: Option<PostscriptNames>, italic_angle: f64, gdef_categories: GdefCategories, glyphsapp_number_values: Option<HashMap<NormalizedLocation, BTreeMap<SmolStr, OrderedFloat<f64>>>>, build_vertical: bool, ) -> Result<StaticMetadata, VariationModelError>

pub fn default_location(&self) -> &NormalizedLocation

The default on all variable axes.

pub fn axis(&self, tag: &Tag) -> Option<&Axis>

pub fn reverse_names(&self) -> HashMap<&str, BTreeSet<NameId>>

Calculate a mapping of existing name text to the sorted set of name ID(s) that provide it.